==> v1.0.0.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/visual/dto/ComponentColumn.java <==
/**
 * 
 */
package org.springblade.visual.dto;

import java.io.Serializable;

import org.springblade.cube.enums.AggregationTypeEnum;
import org.springblade.cube.enums.ColumnAttrEnum;
import org.springblade.cube.enums.DateFormatEnum;
import org.springblade.cube.enums.DimensionTypeEnum;
import org.springblade.cube.enums.NumberFormatEnum;
import org.springblade.cube.enums.ViewColumnTypeEnum;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.NullSerializer;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * @author wookvn
 *
 */
@Data
@ApiModel("大屏组件字段对象")
public class ComponentColumn implements Serializable {
	
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@ApiModelProperty("数据集字段ID")
	private Integer cubeColumnId;
	
	@ApiModelProperty("表名称")
	private String tableName;
	
	@ApiModelProperty("表别名")
	private String tableAliasName;
	
	@ApiModelProperty("字段显示名")
	private String columnTitle;
	
	@ApiModelProperty("字段名")
	private String columnName;
	
	@ApiModelProperty(hidden = true)
	private String columnAliasName;
	
	@ApiModelProperty("字段注释")
	private String columnComment;
	
	@ApiModelProperty("字段片段SQL(仅有虚拟字段使用)")
	private String columnSql;

	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("字段数据展示类型")
	private ViewColumnTypeEnum viewDataType;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("字段维度/指标类型")
	private DimensionTypeEnum dimensionType;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("字段属性(NORMAL-标准字段/VIRTUAL-虚拟字段)")
	private ColumnAttrEnum columnAttr;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("数值类型展示格式")
	private NumberFormatEnum numberDataFormat;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("日期类型展示格式")
	private DateFormatEnum timeDataFormat;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("指标的聚合函数")
	private AggregationTypeEnum aggregationType;
	
	@ApiModelProperty("虚拟字段是否包含聚合函数[1-是/0-否]")
	private Integer virtualAggregationStatus;
	
	@ApiModelProperty("报表和图表的行/列类型")
	private String type;
	
	private Boolean zuan;
	
	private String extJson;

	private String userGroupColumnAliasName;

}

==> v3.4.1.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/visual/dto/ComponentColumn.java <==
/**
 * 
 */
package org.springblade.visual.dto;

import java.io.Serializable;

import org.springblade.cube.enums.AggregationTypeEnum;
import org.springblade.cube.enums.ColumnAttrEnum;
import org.springblade.cube.enums.DimensionTypeEnum;
import org.springblade.cube.enums.WeiduTypeEnum;
import org.springblade.datasource.enums.DateFormatEnum;
import org.springblade.datasource.enums.NumberFormatEnum;
import org.springblade.datasource.enums.ViewColumnTypeEnum;

import com.baomidou.mybatisplus.annotation.TableField;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.NullSerializer;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * @author wookvn
 *
 */
@Data
@ApiModel("大屏组件字段对象")
public class ComponentColumn implements Serializable {
	
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@ApiModelProperty("数据集字段ID")
	private Integer cubeColumnId;
	
	@ApiModelProperty("表名称")
	private String tableName;
	
	@ApiModelProperty("表别名")
	private String tableAliasName;
	
	@ApiModelProperty("字段显示名")
	private String columnTitle;
	
	@ApiModelProperty("字段名")
	private String columnName;
	
	@ApiModelProperty(hidden = true)
	private String columnAliasName;
	
	@ApiModelProperty("字段注释")
	private String columnComment;
	
	@ApiModelProperty("字段片段SQL(仅有虚拟字段使用)")
	private String columnSql;

	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("字段数据展示类型")
	private ViewColumnTypeEnum viewDataType;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("字段维度/指标类型")
	private DimensionTypeEnum dimensionType;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("字段维度类型")
	@TableField(exist = false)
	private WeiduTypeEnum weiduType = WeiduTypeEnum.ROW;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("字段属性(NORMAL-标准字段/VIRTUAL-虚拟字段)")
	private ColumnAttrEnum columnAttr;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("数值类型展示格式")
	private NumberFormatEnum numberDataFormat;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("日期类型展示格式")
	private DateFormatEnum timeDataFormat;
	
	@JsonSerialize(nullsUsing = NullSerializer.class)
	@ApiModelProperty("指标的聚合函数")
	private AggregationTypeEnum aggregationType;
	
	@ApiModelProperty("虚拟字段是否包含聚合函数[1-是/0-否]")
	private Integer virtualAggregationStatus;
	
	@ApiModelProperty("报表和图表的行/列类型")
	private String type;
	
	private Boolean zuan;
	
	private String extJson;

	private String userGroupColumnAliasName;

}
